@@ -2,7 +2,7 @@ import argparse
 import os
 import re
 import sys
-sys.path.append(os.getcwd())
+sys.path.append(os.path.dirname(os.path.abspath(__file__)))
 from templates import (get_main, get_init, get_readme, get_gitignore, get_credentials)
 
 if os.name == 'nt':
